import pandas as pd
import json
import requests
from urllib.parse import urljoin

from sync_amz_data.tasks.utils import MAPING
from sync_amz_data.tasks.datainsert.wg import LADS

class RateLimitError(Exception):
    def __init__(self, retry_after: str = None):
        self.retry_after = retry_after


def request(url_path: str, method: str = "GET", head: dict = None, params: dict = None, body: dict = None, AD = LADS):
    ADS = AD
    resp = requests.session().request(
        method=method,
        url=urljoin(ADS, url_path),
        headers=head,
        params=params,
        json=body,
    )
    if resp.status_code == 429:
        raise RateLimitError(resp.headers.get("Retry-After"))
    if resp.status_code >= 400:
        raise Exception(resp.text)
    return resp.json()


class ReportManageDataLoad:
    def __init__(self, file_path, sheet_name):
        # self.file_path = 'D:/code/test/20240422.xlsx'
        # self.sheet_name = '2024年03月份销售额'
        self.maping = MAPING
        self.heads = {'X-Token': "da4ab6bc5cbf1dfa"}
        self.upcreate_url_path = ""
        self.file_path = file_path
        self.sheet_name = sheet_name


    def data_load(self):
        df = pd.read_excel(self.file_path, sheet_name=self.sheet_name)
        task_df = df[['平台编号', '平台名称', '运营', '国家', '品牌', '回款币种', '回款/余额币种']].copy()
        task_df['运营'] = "文高"
        task_df.rename(
            columns={'平台编号': 'platformNumber', '平台名称': 'platformName', '运营': 'user', '国家': 'country',
                     '品牌': 'brandName', '回款币种': 'currencyCode', '回款/余额币种': 'currencyCodePlatform'},
            inplace=True)
        task_df.currencyCode = task_df.currencyCode.map(self.maping)
        task_df = task_df.dropna()
        user_list = list(set(task_df.user.to_list()))
        json_str = task_df.to_json(orient='records', date_format='iso')
        out_data = json.loads(json_str)
        out = {'user_list': user_list, 'out_data': out_data}
        return out

    def updata_create(self):
        body = self.data_load().get('out_data')
        heads = self.heads
        url_path = self.upcreate_url_path
        tem = request(url_path=url_path, head=heads, body=body, method="POST")
        return tem




# 使用pandas的read_excel函数读取数据



